package com.zy.bms.service;

import com.zy.bms.common.Constant;
import com.zy.bms.config.mqtt.MqttGateway;
import com.zy.bms.model.MqttMsgDto;
import com.zy.bms.common.io.wechat.*;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * 设置设备服务类,发送远程消息
 *
 * @author yang xiao kun
 * create on 2021/2/1
 */
@Component
public class SetToDeviceService {
    @Resource
    private MqttGateway mqttGateway;

    /**
     * 设置音量
     * 铃声音量暂时不可用 ringvol 参数暂时没用
     *
     * @param io 设置参数
     */
    public void setVolume(VolumeSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_VOLUME, io.getDeviceId());
        msg.set("msgvol", io.getMsgVol())
                .set("phonevol", io.getPhoneVol())
                .set("msgtype", 1);
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置定位频率
     *
     * @param io 设置参数
     */
    public void setGpsRate(GpsRateSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_GPS_RATE, io.getDeviceId());
        msg.set("GPS_rate", io.getGpsRate());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 自动接听
     *
     * @param io 设置参数
     */
    public void setAutoAnswer(AnswerSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_AUTO_ANSWER, io.getDeviceId());
        msg.set("autoanswer", io.getAutoAnswer());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置语音播报
     */
    public void sendNews(NewsSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_NEWS, io.getDeviceId());
        msg.set("newstype", io.getNewsType())
                .set("newstime", io.getNewsTime())
                .set("news", io.getNews());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置SOS紧急呼叫
     */
    public void setSOS(SosSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_SOS, io.getDeviceId());
        msg.set("key0_name", io.getKey0Name())
                .set("key0_phone", io.getKey0Phone())
                .set("key1_name", io.getKey1Name())
                .set("key1_phone", io.getKey1Phone())
                .set("key2_name", io.getKey2Name())
                .set("key2_phone", io.getKey2Phone());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 设置持续定位
     */
    public void setContinue(ContinueSetIO io) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto(Constant.M_CODE_CONTINUE_GPS, io.getDeviceId());
        msg.set("highfreq", io.getHighFreq());
        mqttGateway.sendMsgToMqtt(msg.toJson(), io.getTopic());
    }

    /**
     * 服务器返回授权码
     *
     * @param regNum   设备码
     * @param clientId MQTT 客户端码
     * @param password MQTT 客户端连接密码
     */
    public void returnCodeToDevice(String regNum, String clientId, String password) {
        //发送模板消息给设备
        MqttMsgDto msg = new MqttMsgDto();
        msg.setM(Constant.M_CODE_RETURN_CODE);
        msg.setR("$regdtx");
        msg.setT("$regdrx");
        Map<String, Object> data = new HashMap<>();
        data.put("regnum", regNum);
        data.put("deviceid", clientId);
        data.put("password", password);
        msg.setData(data);
        mqttGateway.sendMsgToMqtt(msg.toJson(), Constant.TOPIC_REGISTER_CLIENT);
    }
}
